summaryrefslogtreecommitdiff
path: root/sys/arch/i386/stand/mbr/mbr.S
diff options
context:
space:
mode:
authorMichael Shalayeff <mickey@cvs.openbsd.org>2001-12-15 21:28:46 +0000
committerMichael Shalayeff <mickey@cvs.openbsd.org>2001-12-15 21:28:46 +0000
commit87d94744a2519cd2024d95c0acf57fffa457c0b9 (patch)
treeaca4145415ca9a33925eab18d385fcacc7e4b5ae /sys/arch/i386/stand/mbr/mbr.S
parente3ea8091456a19721d469e18ed662de4f3e85d8f (diff)
first i gave you one of the reasons it mmakes thing better.
second i did not see the final diff. third i never said you should commit this. fourth, 10x for running around offending lusers i'm trying to resolve their problems with.
Diffstat (limited to 'sys/arch/i386/stand/mbr/mbr.S')
-rw-r--r--sys/arch/i386/stand/mbr/mbr.S17
1 files changed, 8 insertions, 9 deletions
diff --git a/sys/arch/i386/stand/mbr/mbr.S b/sys/arch/i386/stand/mbr/mbr.S
index 804a8f81422..1a805d297a4 100644
--- a/sys/arch/i386/stand/mbr/mbr.S
+++ b/sys/arch/i386/stand/mbr/mbr.S
@@ -1,4 +1,4 @@
-/* $OpenBSD: mbr.S,v 1.14 2001/12/15 21:16:10 kjell Exp $ */
+/* $OpenBSD: mbr.S,v 1.15 2001/12/15 21:28:45 mickey Exp $ */
/*
* Copyright (c) 1997 Michael Shalayeff and Tobias Weingartner
@@ -61,9 +61,8 @@
#define DBGMSG(msg) \
movb $msg, %al; \
- /* call Lchr */; \
- .byte 0xe8; \
- .word Lchr - . - 2
+ data32; \
+ call chr
#else /* !DEBUG */
#define DBGMSG(msg)
#endif /* !DEBUG */
@@ -294,15 +293,14 @@ Lmessage:
lodsb # load a byte into %al
testb %al, %al
jz 1f
- /* call Lchr */
- .byte 0xe8
- .word Lchr - . - 2
+ data32
+ call chr
jmp 1b
#
# Lchr: write the error message in %ds:%si to console
#
-Lchr:
+chr:
pushl %eax
#ifndef SERIAL
@@ -321,6 +319,7 @@ Lchr:
popl %edx
#endif
1: popl %eax
+ data32
ret
/* Info messages */
@@ -294,15 +293,14 @@ Lmessage:
jmp 1b
#
-# Lchr: write the error message in %ds:%si to console
+# chr: write the error message in %ds:%si to console
#